@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/kms/KMS_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/kms/KMS_EXPORTS.h>
 
-namespace Aws
-{
-namespace KMS
-{
-namespace Model
-{
-  enum class IncludeKeyMaterial
-  {
-    NOT_SET,
-    ALL_KEY_MATERIAL,
-    ROTATIONS_ONLY
-  };
+namespace Aws {
+namespace KMS {
+namespace Model {
+enum class IncludeKeyMaterial { NOT_SET, ALL_KEY_MATERIAL, ROTATIONS_ONLY };
 
-namespace IncludeKeyMaterialMapper
-{
+namespace IncludeKeyMaterialMapper {
 AWS_KMS_API IncludeKeyMaterial GetIncludeKeyMaterialForName(const Aws::String& name);
 
 AWS_KMS_API Aws::String GetNameForIncludeKeyMaterial(IncludeKeyMaterial value);
-} // namespace IncludeKeyMaterialMapper
-} // namespace Model
-} // namespace KMS
-} // namespace Aws
+}  // namespace IncludeKeyMaterialMapper
+}  // namespace Model
+}  // namespace KMS
+}  // namespace Aws
