@@ -4,29 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class CompressionType
-  {
-    NOT_SET,
-    NONE,
-    GZIP,
-    BZIP2
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class CompressionType { NOT_SET, NONE, GZIP, BZIP2 };
 
-namespace CompressionTypeMapper
-{
+namespace CompressionTypeMapper {
 AWS_S3CRT_API CompressionType GetCompressionTypeForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForCompressionType(CompressionType value);
-} // namespace CompressionTypeMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace CompressionTypeMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
