@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class FilterRuleName
-  {
-    NOT_SET,
-    prefix,
-    suffix
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class FilterRuleName { NOT_SET, prefix, suffix };
 
-namespace FilterRuleNameMapper
-{
+namespace FilterRuleNameMapper {
 AWS_S3CRT_API FilterRuleName GetFilterRuleNameForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForFilterRuleName(FilterRuleName value);
-} // namespace FilterRuleNameMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace FilterRuleNameMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
