@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3-crt/S3Crt_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3-crt/S3Crt_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Crt
-{
-namespace Model
-{
-  enum class ObjectLockLegalHoldStatus
-  {
-    NOT_SET,
-    ON,
-    OFF
-  };
+namespace Aws {
+namespace S3Crt {
+namespace Model {
+enum class ObjectLockLegalHoldStatus { NOT_SET, ON, OFF };
 
-namespace ObjectLockLegalHoldStatusMapper
-{
+namespace ObjectLockLegalHoldStatusMapper {
 AWS_S3CRT_API ObjectLockLegalHoldStatus GetObjectLockLegalHoldStatusForName(const Aws::String& name);
 
 AWS_S3CRT_API Aws::String GetNameForObjectLockLegalHoldStatus(ObjectLockLegalHoldStatus value);
-} // namespace ObjectLockLegalHoldStatusMapper
-} // namespace Model
-} // namespace S3Crt
-} // namespace Aws
+}  // namespace ObjectLockLegalHoldStatusMapper
+}  // namespace Model
+}  // namespace S3Crt
+}  // namespace Aws
