@@ -4,27 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3/S3_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3/S3_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3
-{
-namespace Model
-{
-  enum class BucketType
-  {
-    NOT_SET,
-    Directory
-  };
+namespace Aws {
+namespace S3 {
+namespace Model {
+enum class BucketType { NOT_SET, Directory };
 
-namespace BucketTypeMapper
-{
+namespace BucketTypeMapper {
 AWS_S3_API BucketType GetBucketTypeForName(const Aws::String& name);
 
 AWS_S3_API Aws::String GetNameForBucketType(BucketType value);
-} // namespace BucketTypeMapper
-} // namespace Model
-} // namespace S3
-} // namespace Aws
+}  // namespace BucketTypeMapper
+}  // namespace Model
+}  // namespace S3
+}  // namespace Aws
