@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3/S3_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3/S3_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3
-{
-namespace Model
-{
-  enum class ExistingObjectReplicationStatus
-  {
-    NOT_SET,
-    Enabled,
-    Disabled
-  };
+namespace Aws {
+namespace S3 {
+namespace Model {
+enum class ExistingObjectReplicationStatus { NOT_SET, Enabled, Disabled };
 
-namespace ExistingObjectReplicationStatusMapper
-{
+namespace ExistingObjectReplicationStatusMapper {
 AWS_S3_API ExistingObjectReplicationStatus GetExistingObjectReplicationStatusForName(const Aws::String& name);
 
 AWS_S3_API Aws::String GetNameForExistingObjectReplicationStatus(ExistingObjectReplicationStatus value);
-} // namespace ExistingObjectReplicationStatusMapper
-} // namespace Model
-} // namespace S3
-} // namespace Aws
+}  // namespace ExistingObjectReplicationStatusMapper
+}  // namespace Model
+}  // namespace S3
+}  // namespace Aws
