@@ -4,28 +4,19 @@
  */
 
 #pragma once
-#include <aws/s3tables/S3Tables_EXPORTS.h>
 #include <aws/core/utils/memory/stl/AWSString.h>
+#include <aws/s3tables/S3Tables_EXPORTS.h>
 
-namespace Aws
-{
-namespace S3Tables
-{
-namespace Model
-{
-  enum class TableType
-  {
-    NOT_SET,
-    customer,
-    aws
-  };
+namespace Aws {
+namespace S3Tables {
+namespace Model {
+enum class TableType { NOT_SET, customer, aws };
 
-namespace TableTypeMapper
-{
+namespace TableTypeMapper {
 AWS_S3TABLES_API TableType GetTableTypeForName(const Aws::String& name);
 
 AWS_S3TABLES_API Aws::String GetNameForTableType(TableType value);
-} // namespace TableTypeMapper
-} // namespace Model
-} // namespace S3Tables
-} // namespace Aws
+}  // namespace TableTypeMapper
+}  // namespace Model
+}  // namespace S3Tables
+}  // namespace Aws
